<?php

namespace Crm\News\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Crm\News\Http\Resources\NewsResource;
use Crm\News\Http\Resources\NewsCollection;
use Crm\News\Scopes\NewsPublicScope;
use Crm\News\Models\News;

class NewsPublicController extends BaseController
{

    /**
     * Show news's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = News::pushScope(new RequestScope())
            ->pushScope(new NewsPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $news = new NewsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('news::news.names'))
            ->view('news::public.news.index')
            ->data(compact('news', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show news.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = News::findBySlug($slug);
        $data = new NewsResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('news::news.name'))
            ->view('news::public.news.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
