<?php

namespace Crm\News\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\News\Events\NewsWorkflow as NewsWorkflowEvent;
use Crm\News\Notifications\NewsWorkflow as NewsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class NewsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(NewsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $news is submitted.
     *
     * @param NewsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(NewsWorkflowEvent $event)
    {
        $client = $event->news->client;
        Notification::send($client, new NewsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $news is published.
     *
     * @param NewsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(NewsWorkflowEvent $event)
    {
        $client = $event->news->client;
        Notification::send($client, new NewsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $news is approved.
     *
     * @param NewsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(NewsWorkflowEvent $event)
    {
        $client = $event->news->client;
        Notification::send($client, new NewsWorkflowNotification($event));
    }

    /**
     * Handles the $news workflow event as a listener.
     *
     * @param NewsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(NewsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
