<?php

namespace Crm\News\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\News\Models\News;

class NewsPolicy
{


    /**
     * Determine if the given user can view the news.
     *
     * @param Authenticatable $user
     * @param News $news
     *
     * @return bool
     */
    public function view(Authenticatable $user, News $news)
    {
        if ($authUser->canDo('news.news.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $news->is_owner;
    }

    /**
     * Determine if the given user can create a news.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('news.news.create');
    }

    /**
     * Determine if the given user can update the given news.
     *
     * @param Authenticatable $user
     * @param News $news
     *
     * @return bool
     */
    public function update(Authenticatable $user, News $news)
    {
        if ($user->canDo('news.news.edit') && $user->isAdmin()) {
            return true;
        }

        return $news->is_owner;
    }

    /**
     * Determine if the given user can delete the given news.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, News $news)
    {
        return $news->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
